using System;
using System.Collections.Generic;
using System.Linq;
using System.Threading.Tasks;
using Microsoft.AspNetCore.Builder;
using Microsoft.AspNetCore.Hosting;
using Microsoft.AspNetCore.HttpsPolicy;
using Microsoft.Extensions.Configuration;
using Microsoft.Extensions.DependencyInjection;
using Microsoft.Extensions.Hosting;
using MVVMDataLayer;
using MVVMViewModelLayer;
using Microsoft.EntityFrameworkCore;

namespace MVVMSample {
  public class Startup {
    public Startup(IConfiguration configuration) {
      Configuration = configuration;
    }

    public IConfiguration Configuration { get; }

    // This method gets called by the runtime. Use this method to add services to the container.
    public void ConfigureServices(IServiceCollection services) {
      services.AddControllersWithViews();

      // Inject your application services
      InjectAppServices(services);
    }

    private void InjectAppServices(IServiceCollection services) {
      // Get connection string from appsettings.json
      string cnn = Configuration["ConnectionStrings:AdvWorksConnectionString"];

      // Add AdventureWorks DbContext object
      services.AddDbContext<AdvWorksDbContext>(options => options.UseSqlServer(cnn));

      // The next two lines are for session state
      services.AddDistributedMemoryCache();
      services.AddSession();
      
      // Add Classes for Scoped DI
      services.AddScoped<IProductRepository, ProductRepository>();
      services.AddScoped<ProductViewModel>();
    }

    // This method gets called by the runtime. Use this method to configure the HTTP request pipeline.
    public void Configure(IApplicationBuilder app, IWebHostEnvironment env) {
      if (env.IsDevelopment()) {
        app.UseDeveloperExceptionPage();
      } else {
        app.UseExceptionHandler("/Home/Error");
        // The default HSTS value is 30 days. You may want to change this for production scenarios, see https://aka.ms/aspnetcore-hsts.
        app.UseHsts();
      }
      app.UseHttpsRedirection();
      app.UseStaticFiles();

      app.UseRouting();

      // Call this after the call to the 'UseRouting()' method
      app.UseSession();

      app.UseAuthorization();

      app.UseEndpoints(endpoints => {
        endpoints.MapControllerRoute(
                  name: "default",
                  pattern: "{controller=Home}/{action=Index}/{id?}");
      });
    }
  }
}
